@@ -33,6 +33,7 @@ class IOBoard:
       if resp and resp[1] == 0xF1:
         self.have_IO_Board = True
         if True or DEBUG_I2C: print ('Have IO_Board')
+        self.hardware.ImmediateChange('hermes_iob_rxin')
       else:
         self.have_board_counter -= 1
         if self.have_board_counter == 0:
@@ -41,7 +42,6 @@ class IOBoard:
     if not self.have_IO_Board:
       return
     if self.hardware.tx_frequency != self.current_tx_freq and time.time() - self.tx_timer > 0.50:
-      #self.FanLevel(64)
       self.current_tx_freq = self.hardware.tx_frequency
       self.tx_timer = time.time()
       tx = self.current_tx_freq		# Send Tx frequency to IO Board
@@ -50,11 +50,13 @@ class IOBoard:
       self.hardware.WriteI2C(0x7d, 0x1D, 2, (tx >> 16) & 0xFF)
       self.hardware.WriteI2C(0x7d, 0x1D, 3, (tx >>  8) & 0xFF)
       self.hardware.WriteI2C(0x7d, 0x1D, 13, tx        & 0xFF)	# LSB
+      #self.Receive()
   def Receive(self, register=0):	# Get the response from the IO board
     if not self.have_IO_Board:
       return
-    #print ('IO Board: 0x%X 0x%X 0x%X 0x%X 0x%X' % tuple(Hardware.io_board.Receive(0)))
-    return self.hardware.ReadI2C(0x7d, 0x1D, register)
+    ret = self.hardware.ReadI2C(0x7d, 0x1D, register)
+    #print ('IO Board: 0x%X 0x%X 0x%X 0x%X 0x%X' % tuple(ret))
+    return ret
   def FanLevel(self, level):
     if not self.have_IO_Board:
       return
